@@ -27,8 +27,10 @@ if 'celex' in settings.INSTALLED_APPS:
 
 if 'mysql' in settings.DATABASES['default']['ENGINE']:
     from .helper import mysql_ur_string_lookup as UR_LOOKUP
+    from .helper import mysql_speaker_center as SPEAKER_SQL
 else:
     from .helper import pg_ur_string_lookup as UR_LOOKUP
+    from .helper import pg_speaker_center as SPEAKER_SQL
 
 from .helper import fetch_buckeye_resource,reorganize
 from .managers import BulkManager
@@ -108,19 +110,7 @@ class Speaker(caching.base.CachingMixin,models.Model):
     def getCenter(self):
         from django.db import connection
         cursor = connection.cursor()
-        cursor.execute("""Select avg(AvgF1), avg(AvgF2) FROM (SELECT StressVowel as Vowel,
-avg(StrVowelF1) as AvgF1,
-avg(StrVowelF2) as AvgF2
- FROM buckeyebrowser_wordtoken
-Inner join buckeyebrowser_wordtype
-ON buckeyebrowser_wordtype.id =buckeyebrowser_wordtoken.WordType_id
-Inner join buckeyebrowser_dialog
-ON buckeyebrowser_dialog.id = buckeyebrowser_wordtoken.Dialog_id
-Inner join buckeyebrowser_speaker
-ON buckeyebrowser_speaker.id = buckeyebrowser_dialog.Speaker_id
-WHERE CVSkel = 'CVC'
-AND buckeyebrowser_dialog.Speaker_id = %s
-Group by StressVowel) AS averages""",[self.pk])
+        cursor.execute(SPEAKER_SQL,[self.pk])
         center = cursor.fetchone()
         return (center[0],center[1])
 
